==> ecip-codegen-0.4.19.tgz: package/src/api/vue/genTable/gencodeTableApi.js <==
import request from 'ecip-web/utils/request'

export const getData = (params, data) => { //  分页查询表单信息
  return request({
    url: 'api/v1/table/gencodeTable/data',
    method: 'post',
    params: params,
    data: data
  })
}

export const findDatabaseTable = (params, data) => { //  查找数据库里的表
  return request({
    url: 'api/v1/table/gencodeTable/databaseTable',
    method: 'post',
    params: params,
    data: data
  })
}

export const listTable = (templateType) => { //  查找数据库里的表
  return request({
    url: 'api/v1/table/gencodeTable/listTable',
    method: 'get',
    params: { templateType: templateType }
  })
}

export const getDatasourceTree = () => { //  查找数据源树
  return request({
    url: 'api/v1/table/gencodeTable/findDatasourceTree',
    method: 'get'
  })
}

export const getDictTypeList = () => { //  查找数据字典类型
  return request({
    url: 'api/v1/table/gencodeTable/getDictType',
    method: 'get'
  })
}

export const getById = (id) => { //  编辑时根据id查询表单信息
  return request({
    url: `api/v1/table/gencodeTable/${id}`,
    method: 'get'
  })
}
export const getTbConfigurationById = (id) => { //  编辑时根据id查询表单信息(含列信息)
  return request({
    url: `api/v1/table/gencodeTable/tbConfiguration/${id}`,
    method: 'get'
  })
}

export const databaseImportForm = (data) => { //  数据库导入表单
  return request({
    url: `api/v1/table/gencodeTable/databaseImportForm`,
    method: 'post',
    data: data
  })
}

export const updateSort = (id, params) => { //  表单排序
  return request({
    url: `api/v1/table/gencodeTable/updateSort/${id}`,
    method: 'put',
    params: params
  })
}

export const removeByIds = (ids) => { //  批量移除表单
  return request({
    url: 'api/v1/table/gencodeTable/removeByIds',
    method: 'delete',
    data: ids || []
  })
}

export const deleteByIds = (ids) => { //  批量删除表单
  return request({
    url: 'api/v1/table/gencodeTable/deleteByIds',
    method: 'delete',
    data: ids || []
  })
}

export const saveFormConfig = (data) => { //  保存表单
  return request({
    url: 'api/v1/table/gencodeTable/submitFormGuide',
    method: 'post',
    data: data
  })
}

// export const update = (id, data) => { //  更新表单
//   return request({
//     url: `api/v1/table/gencodeTable/${id}`,
//     method: 'put',
//     data: data
//   })
// }

==> ecip-codegen-0.4.20.tgz: package/src/api/vue/genTable/gencodeTableApi.js <==
import request from 'ecip-web/utils/request'

export const getData = (params, data) => { //  分页查询表单信息
  return request({
    url: 'api/v1/table/gencodeTable/data',
    method: 'post',
    params: params,
    data: data
  })
}

export const findDatabaseTable = (params, data) => { //  查找数据库里的表
  return request({
    url: 'api/v1/table/gencodeTable/databaseTable',
    method: 'post',
    params: params,
    data: data
  })
}

export const listTable = (templateType) => { //  查找数据库里的表
  return request({
    url: 'api/v1/table/gencodeTable/listTable',
    method: 'get',
    params: { templateType: templateType }
  })
}

export const getDatasourceTree = () => { //  查找数据源树
  return request({
    url: 'api/v1/table/gencodeTable/findDatasourceTree',
    method: 'get'
  })
}

export const getDictTypeList = () => { //  查找数据字典类型
  return request({
    url: 'api/v1/table/gencodeTable/getDictType',
    method: 'get'
  })
}

export const getById = (id) => { //  编辑时根据id查询表单信息
  return request({
    url: `api/v1/table/gencodeTable/${id}`,
    method: 'get'
  })
}
export const getTbConfigurationById = (id) => { //  编辑时根据id查询表单信息(含列信息)
  return request({
    url: `api/v1/table/gencodeTable/tbConfiguration`,
    method: 'get',
    params: { id: id }
  })
}

export const getTreeRowsData = (type) => {
  return request({
    url: `api/v1/column/tableColumn/getTreeRowsData/${type}`,
    method: 'get'
  })
}

export const databaseImportForm = (data) => { //  数据库导入表单
  return request({
    url: `api/v1/table/gencodeTable/databaseImportForm`,
    method: 'post',
    data: data
  })
}

export const updateSort = (id, params) => { //  表单排序
  return request({
    url: `api/v1/table/gencodeTable/updateSort/${id}`,
    method: 'put',
    params: params
  })
}

export const removeByIds = (ids) => { //  批量移除表单
  return request({
    url: 'api/v1/table/gencodeTable/removeByIds',
    method: 'delete',
    data: ids || []
  })
}

export const deleteByIds = (ids) => { //  批量删除表单
  return request({
    url: 'api/v1/table/gencodeTable/deleteByIds',
    method: 'delete',
    data: ids || []
  })
}

export const saveFormConfig = (data) => { //  保存表单
  return request({
    url: 'api/v1/table/gencodeTable/submitFormGuide',
    method: 'post',
    data: data
  })
}

// export const update = (id, data) => { //  更新表单
//   return request({
//     url: `api/v1/table/gencodeTable/${id}`,
//     method: 'put',
//     data: data
//   })
// }
